@@ -268,8 +268,11 @@
     (gtk-box-pack-start outer-box remove #f #t 0)
     (gtk-widget-show remove)
 
-    (gtk-signal-connect lyst "select_child" (lambda (child)
-    					      (pk 'selected child)))
+    (gtk-signal-connect lyst "select_child" 
+			(lambda (child)
+			  (pk 'selected child
+			      (gtk-list-child-position lyst child))))
+
     ; unselect_child is never emited...
     (gtk-signal-connect lyst "unselect_child" (lambda (child)
 					      (pk 'unselected child)))
@@ -320,7 +323,18 @@
     '()))
 
 (define create-rulers #f)
-(define create-text #f)
+
+(define-test create-text "text"
+  (let* ((t (gtk-text-new #f #f)))
+    (gtk-box-pack-start outer-box t #t #t 0)
+    (gtk-widget-show t)
+
+    (gtk-widget-realize t)
+    (gtk-text-insert t #f "white" "green" "Hallo!\n" -1)
+    (gtk-text-insert t #f "yellow" "red" "Huhu!\n" -1)
+    (gtk-text-thaw t)
+
+    '()))
 
 (define-test create-notebook "notebook" 
   (let ((notebook (gtk-notebook-new)))
@@ -420,6 +434,43 @@
 
 (define create-test #f)
 
+(define (yes-or-no? question)
+  (let ((d (gtk-dialog-new))
+	(l (gtk-label-new question))
+	(y (gtk-button-new-with-label "Yes"))
+	(n (gtk-button-new-with-label "No"))
+
+	(answer #f))
+    (gtk-window-set-title d "Yes or No?")
+    (gtk-misc-set-alignment l 0.5 0.5)
+    (gtk-box-pack-start (gtk-dialog-vbox d) l #f #f 0)
+    (gtk-box-pack-start (gtk-dialog-action-area d) y #t #t 3)
+    (gtk-box-pack-start (gtk-dialog-action-area d) n #t #t 3)
+    (gtk-widget-show l)
+    (gtk-widget-show y)
+    (gtk-widget-show n)
+    (gtk-widget-show d)
+
+    (gtk-signal-connect d "delete_event"
+			(lambda (ev)
+			  (gtk-main-quit) #t))
+    (gtk-signal-connect n "clicked"
+			(lambda () 
+			  (gtk-widget-destroy d)
+			  (gtk-main-quit)))
+    (gtk-signal-connect y "clicked"
+			(lambda () 
+			  (set! answer #t)
+			  (gtk-widget-destroy d)
+			  (gtk-main-quit)))
+
+    (gtk-grab-add d)
+    (gtk-main)
+    (if (not (gtk-destroyed? d))
+	(gtk-grab-remove d))
+
+    answer))
+
 (define (create-main-window)
   (define buttons
     `(("buttons" ,create-buttons)
@@ -457,31 +508,30 @@
 	(box3   (gtk-vbox-new #f 10))
 	(gc-but (gtk-button-new-with-label "gc"))
 	(button (gtk-button-new-with-label "close")))
-
+    
     (gtk-widget-set-name window "main window")
-    (gtk-widget-set-uposition window 20 20)
-    (gtk-container-add window box1)
-    (gtk-widget-show box1)
-    (gtk-container-border-width box2 10)
-    (gtk-box-pack-start box1 box2 #t #t 0)
-    (gtk-widget-show box2)
+       (gtk-widget-set-uposition window 20 20)
+       (gtk-container-add window box1)
+       (gtk-widget-show box1)
+       (gtk-container-border-width box2 10)
+       (gtk-box-pack-start box1 box2 #t #t 0)
+       (gtk-widget-show box2)
     
     (for-each (lambda (b)
 		(let ((button (gtk-button-new-with-label (car b))))
 		  (if (cadr b)
 		      (gtk-signal-connect button "clicked" (cadr b))
 		      (gtk-widget-set-sensitive button #f))
-		  (gtk-box-pack-start box2 button #t #t 0)
-		  (gtk-widget-show button)))
+		     (gtk-box-pack-start box2 button #t #t 0)
+		     (gtk-widget-show button)))
 	      buttons)
-
+       
     (gtk-box-pack-start box1 separator #f #t 0)
     (gtk-widget-show separator)
     (gtk-container-border-width box3 10)
     (gtk-box-pack-start box1 box3 #f #t 0)
     (gtk-widget-show box3)
-    (gtk-signal-connect gc-but "clicked" 
-			(lambda () (gc)))
+    (gtk-signal-connect gc-but "clicked" gc)
     (gtk-box-pack-start box3 gc-but #t #t 0)
     (gtk-widget-show gc-but)
     (gtk-signal-connect button "clicked" gtk-exit)
@@ -490,6 +540,12 @@
     (gtk-widget-grab-default button)
     (gtk-widget-show button)
 
+    (gtk-signal-connect window "delete_event" 
+			(lambda (ev) 
+			  (if (yes-or-no? "Quit?")
+			      (gtk-exit))
+			  #f))
+    
     (gtk-widget-show window)))
 
 (define break-iteration #f)
