@@ -39,7 +39,7 @@
    /gmix/Balance/Ratio=0.5
    /filemanager/Panel Display/html=1
 
-   If the pathname starts with '#', then instead of being a ~/.gnome relative
+   If the pathname starts with '=', then instead of being a ~/.gnome relative
    file, it is an abolute pathname, example:
 
    =/home/miguel/.mc.ini=/Left Panel/reverse=1
@@ -94,7 +94,7 @@ typedef struct TProfile {
 
 typedef struct {
 	char *file, *section, *key, *def;
-	char *path;
+	char *path, *opath;
 } ParsedPath;
 
 /*
@@ -113,7 +113,7 @@ static TProfile *Base = 0;
 static void
 release_path (ParsedPath *p)
 {
-	g_free (p->path);
+	g_free (p->opath);
 	g_free (p);
 }
 
@@ -123,17 +123,19 @@ parse_path (char *path)
 	ParsedPath *p = g_malloc (sizeof (ParsedPath));
 	char *sep;
 
-	if (*path == '='){
+	if (*path == '/' || prefix == NULL)
+		p->opath = strdup (path);
+	else
+		p->opath = g_copy_strings (prefix, path, NULL);
+
+	p->path = p->opath;
+	
+	if (*p->path == '='){
 		sep = "=";
-		path++;
+		p->path++;
 	} else
 		sep = "/=";
 	
-	if (*path == '/' || prefix == NULL)
-		p->path = strdup (path);
-	else
-		p->path = gnome_copy_strings (prefix, path, NULL);
-
 	p->file    = strtok (p->path, sep);
 	p->section = strtok (NULL, "/=");
 	p->key     = strtok (NULL, "/=");
@@ -141,8 +143,7 @@ parse_path (char *path)
 
 	/* Was it a Gnome-relative pathname? */
 	if (*sep == '/'){
-		char *f = gnome_file_and_dir_concat (gnome_file_user_home_dir(), 
-						     p->file);
+		char *f = g_concat_dir_and_file (gnome_user_dir, p->file);
 		p->file = f;
 	}
 	return p;
@@ -565,7 +566,8 @@ gnome_config_get_string (char *path)
 	
 	pp = parse_path (path);
 	r = access_config (LOOKUP, pp->section, pp->key, pp->def, pp->file);
-	r = strdup (r);
+	if (r)
+		r = strdup (r);
 	release_path (pp);
 	return r;
 }
@@ -599,3 +601,12 @@ gnome_config_set_prefix (char *path)
 {
 	prefix = strdup (path);
 }
+
+void
+gnome_config_drop_prefix (void)
+{
+	if (!prefix)
+		return;
+	free (prefix);
+	prefix = 0;
+}
