@@ -29,6 +29,9 @@ void gnome_config_clean_file     (char *path);
 /* This routine drops all of the information related to /file/section */
 void gnome_config_clean_section  (char *path);
 
+void gnome_config_set_prefix (char *path);
+void gnome_config_drop_prefix (void);
+
 END_GNOME_DECLS
 
 #endif
