@@ -2,7 +2,7 @@
 #define LIBGNOME_H
 
 #include "libgnome/gnome-defs.h"
-#include "libgnome/gnome-file.h"
+#include "libgnome/gnome-util.h"
 #include "libgnome/gnome-hook.h"
 #include "libgnome/gnome-config.h"
 #include "libgnome/gnome-dns.h"
