@@ -48,8 +48,10 @@ gnome_property_configurator_request (GnomePropertyConfigurator *th,
 {
 	int (*cb)(GnomePropertyRequest);
 
-	cb = (int (*)(GnomePropertyRequest))(g_list_nth (th->props,
-							 gtk_notebook_current_page (th->notebook))->data);
+	cb = (int (*)(GnomePropertyRequest))
+		(g_list_nth
+		 (th->props,
+		  gtk_notebook_current_page (GTK_NOTEBOOK (th->notebook)))->data);
 
 
 	// printf ("request %d %x\n", gtk_notebook_current_page (th->notebook), cb);
