@@ -11,7 +11,9 @@ typedef struct {
 
 /* This is the first parameter to the callback function */
 typedef enum {
-	GNOME_PROPERTY_APPLY
+	GNOME_PROPERTY_READ,
+	GNOME_PROPERTY_WRITE,
+	GNOME_PROPERTY_APPLY,
 } GnomePropertyRequest;
 
 GnomePropertyConfigurator *gnome_property_configurator_new     (void);
