@@ -4,6 +4,8 @@
 #include "libgnome/gnome-defs.h"
 #include "libgnomeui/gnome-colors.h"
 #include "libgnomeui/gnome-color-selector.h"
+#include "libgnomeui/gnome-messagebox.h"
+#include "libgnomeui/gnome-pixmap.h"
 
 BEGIN_GNOME_DECLS
 
