@@ -1,4 +1,4 @@
-#!@GNOMEG@
+#!@GNOMEG@ -s
 ;; -*- scheme -*-
 !#
 
