@@ -4,6 +4,7 @@
 #pragma interface
 #include "screensaver.h"
 #include <signal.h>
+#include <string.h>
 
 enum {
 	XLMP_NO_ARG,
@@ -67,6 +68,33 @@ struct XLockModePar {
 		return (val) ? val : def;
 	}
 
+	void setExecArgs (XLockMore *xm) {
+		gchar *rv;
+		gchar *v = getVal ();
+
+		switch (type) {
+		case XLMP_BOOL_ARG:
+			rv = new gchar [strlen (option) + 2];
+			*rv = (strcasecmp (v, "true")) ? '+' : '-';
+			strcpy (rv+1, option);
+
+			xm->addArg (rv);
+
+			delete [] rv;
+
+			break;
+		default:
+			rv = new gchar [strlen (option) + 2];
+			*rv = '-';
+			strcpy (rv+1, option);
+
+			xm->addArg (rv);
+			xm->addArg (v);
+
+			delete [] rv;
+		}
+	}
+
 	XLockModePar (gchar *option, gchar *comment, int type, gchar *d);
 	~XLockModePar ();
 };
